Stan Math Library: stan/math/prim/scal/fun/modified_bessel_first_kind.hpp Source File

| Stan Math Library 2.10.0 reverse mode automatic differentiation

- Main Page
- Modules
- Namespaces
- Classes
- Files

- File List
- File Members

modified_bessel_first_kind.hpp
Go to the documentation of this file.
1 #ifndef STAN_MATH_PRIM_SCAL_FUN_MODIFIED_BESSEL_FIRST_KIND_HPP
2 #define STAN_MATH_PRIM_SCAL_FUN_MODIFIED_BESSEL_FIRST_KIND_HPP
3
4 #include <boost/math/special_functions/bessel.hpp>
5 #include <stan/math/prim/scal/err/check_not_nan.hpp>
6
7 namespace stan {
8 namespace math {
9
37 template<typename T2>
38 inline T2
39 modified_bessel_first_kind(const int v, const T2 z) {
40 using stan::math::check_not_nan;
41 check_not_nan("modified_bessel_first_kind", "z", z);
42
43 return boost::math::cyl_bessel_i(v, z);
44 }
45
46 }
47 }
48
49 #endif
check_not_nan.hpp
stan::math::check_not_nan
bool check_not_nan(const char *function, const char *name, const T_y &y)
Return true if y is not NaN.
Definition: check_not_nan.hpp:63
stan
Definition: log_sum_exp.hpp:8
stan::math::modified_bessel_first_kind
fvar< T > modified_bessel_first_kind(int v, const fvar< T > &z)
Definition: modified_bessel_first_kind.hpp:15

[ Stan Home Page ] © 2011–2016, Stan Development Team.